@@ -164,32 +164,32 @@ class Foreperson:
         keys = recipe.keys()
         # Populate information from the visit section
         if 'visit' in keys:
-            self.data_source.origin.id = self.recipe['visit']['visit id']
-            if 'date' in self.recipe['visit'].keys():
-                self.data_state.origin.date = datetime.strptime(self.recipe['visit']['date'], '%Y-%m-%d')
+            self.data_source.origin.id = recipe['visit']['visit id']
+            if 'date' in recipe['visit'].keys():
+                self.data_state.origin.date = datetime.strptime(recipe['visit']['date'], '%Y-%m-%d')
                 self.data_source.origin.year = self.data_state.origin.date.year()
-            if 'local contact' in self.recipe['visit'].keys():
-                self.data_source = self.recipe['visit']['local contact']
-            if 'user' in self.recipe['visit'].keys():
-                self.creator.name = self.recipe['visit']['user']
-            if 'affiliation' in self.recipe['visit'].keys():
-                self.creator.affiliation = self.recipe['visit']['user affiliation']
+            if 'local contact' in recipe['visit'].keys():
+                self.data_source = recipe['visit']['local contact']
+            if 'user' in recipe['visit'].keys():
+                self.creator.name = recipe['visit']['user']
+            if 'affiliation' in recipe['visit'].keys():
+                self.creator.affiliation = recipe['visit']['user affiliation']
         else:
             raise ValueError("No visit given in {}. You must at least give a visit id".format(yaml_file))
         # Populate informatio from the information section
         if 'instrument' in keys:
-            self.data_source.experiment.instrument = self.recipe['instrument']
-            self.reduction.parser = function_map[self.recipe['instrument']]
+            self.data_source.experiment.instrument = recipe['instrument']
+            self.reduction.parser = function_map[recipe['instrument']]
         # Populate cropping information
         if 'crop' in keys:
-            self.reduction.crop_function = function_map[self.recipe['crop']['method']]
-            if 'kwargs' in self.recipe['crop']:
-                self.reduction.crop_kwargs = self.recipe['crop']['kwargs']
+            self.reduction.crop_function = function_map[recipe['crop']['method']]
+            if 'kwargs' in recipe['crop']:
+                self.reduction.crop_kwargs = recipe['crop']['kwargs']
         # Populate background subtraction method
         if 'background' in keys:
-            self.reduction.bkg_function = function_map[self.recipe['background']['method']]
-            if 'kwargs' in self.recipe['background']:
-                self.reduction.bkg_kwargs = self.recipe['background']['kwargs']
+            self.reduction.bkg_function = function_map[recipe['background']['method']]
+            if 'kwargs' in recipe['background']:
+                self.reduction.bkg_kwargs = recipe['background']['kwargs']
 
             the_boss.metadata['data source']['origin']['experiment date'] = str(datetime.datetime.now().date())
         # Populate the setup information
